==> web-8.0.0.tgz: package/lib/combo/ComboBasic.js <==
import * as React from "react";
import ComboInp from "./ComboInp";
import * as Immutable from "immutable";
import { SlideBox } from "../animate/index";
import { slideOther, event } from "../util/autoSlideUp";
const wrapComboHC = (Drop, comboType) => {
    var _a;
    return _a = class extends React.PureComponent {
            constructor(props) {
                super(props);
                this.eventId = new Date().getTime().toString();
                this.bindSelectFn = (fn) => {
                    this.selectFn = fn;
                };
                this.dropToggle = (e) => {
                    slideOther(e.nativeEvent, this.eventId);
                    this.setState(pre => ({
                        drop: !pre.drop,
                    }));
                };
                this.documentClickFn = () => {
                    this.setState({
                        drop: false,
                    });
                };
                this.initSelect = (selected) => {
                    const { renderCallback } = this.props;
                    this.setState({
                        selected: selected
                    }, () => {
                        if (renderCallback) {
                            const { field, clickCallback } = this.props;
                            const { selected } = this.state;
                            clickCallback(selected.toJS(), field);
                        }
                    });
                };
                this.changeSelect = (selected, node) => {
                    const { clickCallback, field, multiply } = this.props;
                    this.setState((pre) => {
                        return {
                            selected: selected,
                            drop: !multiply ? false : pre.drop
                        };
                    }, () => {
                        const { selected } = this.state;
                        clickCallback(selected.toJS(), field, node);
                    });
                };
                this.state = this.initState();
                this.initFieldObj(props);
                const { maxHeight } = props;
                this.dropStyle = { maxHeight: maxHeight, };
            }
            initFieldObj(props) {
                const { idField, textField, multiply, itemIcon, defaultVal, noSearch, field, clickOrCheckForbid, } = props;
                const common = {
                    idField: idField,
                    textField: textField,
                    multiply,
                    noSearch,
                    itemIcon,
                    defaultVal: `${defaultVal}`,
                    clickOrCheckForbid,
                    field
                };
                if (comboType === "list") {
                    this.filedObj = Immutable.fromJS(common);
                }
                else {
                    const { childField, noSearch, } = props;
                    let treeField = Object.assign(common, { childField, noSearch });
                    this.filedObj = Immutable.fromJS(treeField);
                }
            }
            initState() {
                return {
                    drop: false,
                    selected: Immutable.List([]),
                };
            }
            componentDidMount() {
                event.on(this.eventId, this.documentClickFn);
            }
            componentWillUnmount() {
                event.remove(this.eventId);
            }
            render() {
                const { formatterVal, noIcon, multiply, tit, width, data, dropWidth, noRequire, formatterDropItem, directionUp, ableClear, initComboVal } = this.props;
                const { selected, drop } = this.state;
                const palceholder = tit ? tit : multiply ? "多选" : "单选";
                const activeName = drop ? "autoSlideUp" : "";
                return (React.createElement("div", { className: "g-combo " + activeName, "data-event": this.eventId, style: { width: width, } },
                    React.createElement(ComboInp, { drop: drop, tit: palceholder, selected: selected, formatterVal: formatterVal, slideFn: this.dropToggle, noicon: noIcon, ableClear: ableClear, noRequire: noRequire, clearFn: this.selectFn }),
                    React.createElement("div", { className: `m-drop ${directionUp ? "direction-up" : ""}`, style: dropWidth ? { width: dropWidth } : undefined },
                        React.createElement(SlideBox, { slide: drop, directionUp: directionUp },
                            React.createElement(Drop, { filedObj: this.filedObj, data: data, changeSelect: this.changeSelect, selected: selected, dropStyle: this.dropStyle, initSelect: this.initSelect, initComboVal: initComboVal, formatterDropItem: formatterDropItem, clickMethod: this.bindSelectFn })))));
            }
        },
        _a.defaultProps = {
            idField: "id",
            textField: "text",
            childField: "children",
            width: 240,
            maxHeight: 240,
            defaultVal: "",
            clickOrCheckForbid: function () {
                return false;
            }
        },
        _a;
};
export default wrapComboHC;

==> web-9.0.0.tgz: package/lib/combo/ComboBasic.js <==
import * as React from "react";
import ComboInp from "./ComboInp";
import * as Immutable from "immutable";
import { SlideBox } from "../animate/index";
import { slideOther, event } from "../util/autoSlideUp";
const wrapComboHC = (Drop, comboType) => {
    var _a;
    return _a = class extends React.PureComponent {
            constructor(props) {
                super(props);
                this.eventId = `${new Date().getTime().toString()}-${this.props.field}`;
                this.bindSelectFn = (fn) => {
                    this.selectFn = fn;
                };
                this.dropToggle = (e) => {
                    slideOther(e.nativeEvent, this.eventId);
                    this.setState(pre => ({
                        drop: !pre.drop,
                    }));
                };
                this.documentClickFn = () => {
                    this.setState({
                        drop: false,
                    });
                };
                this.initSelect = (selected) => {
                    const { renderCallback } = this.props;
                    this.setState({
                        selected: selected
                    }, () => {
                        if (renderCallback) {
                            const { field, clickCallback } = this.props;
                            const { selected } = this.state;
                            clickCallback(selected.toJS(), field);
                        }
                    });
                };
                this.changeSelect = (selected, node) => {
                    const { clickCallback, field, multiply } = this.props;
                    this.setState((pre) => {
                        return {
                            selected: selected,
                            drop: !multiply ? false : pre.drop
                        };
                    }, () => {
                        const { selected } = this.state;
                        clickCallback(selected.toJS(), field, node);
                    });
                };
                this.state = this.initState();
                this.initFieldObj(props);
                const { maxHeight } = props;
                this.dropStyle = { maxHeight: maxHeight, };
            }
            initFieldObj(props) {
                const { idField, textField, multiply, itemIcon, defaultVal, noSearch, field, clickOrCheckForbid, } = props;
                const common = {
                    idField: idField,
                    textField: textField,
                    multiply,
                    noSearch,
                    itemIcon,
                    defaultVal: `${defaultVal}`,
                    clickOrCheckForbid,
                    field
                };
                if (comboType === "list") {
                    this.filedObj = Immutable.fromJS(common);
                }
                else {
                    const { childField, noSearch, } = props;
                    let treeField = Object.assign(common, { childField, noSearch });
                    this.filedObj = Immutable.fromJS(treeField);
                }
            }
            initState() {
                return {
                    drop: false,
                    selected: Immutable.List([]),
                };
            }
            componentDidMount() {
                event.on(this.eventId, this.documentClickFn);
            }
            componentWillUnmount() {
                event.remove(this.eventId);
            }
            renderCombox() {
                const { formatterVal, noIcon, multiply, tit, width, data, dropWidth, noRequire, formatterDropItem, directionUp, ableClear, initComboVal, disabled } = this.props;
                const { selected, drop } = this.state;
                const palceholder = tit ? tit : multiply ? "多选" : "单选";
                const activeName = drop ? "autoSlideUp" : "";
                return (React.createElement("div", { className: "g-combo " + activeName, "data-event": this.eventId, style: { width: width, } },
                    React.createElement(ComboInp, { drop: drop, tit: palceholder, selected: selected, formatterVal: formatterVal, slideFn: this.dropToggle, disabled: disabled, noicon: noIcon, ableClear: ableClear, noRequire: noRequire, clearFn: this.selectFn }),
                    React.createElement("div", { className: `m-drop ${directionUp ? "direction-up" : ""}`, style: dropWidth ? { width: dropWidth } : undefined },
                        React.createElement(SlideBox, { slide: drop, directionUp: directionUp },
                            React.createElement(Drop, { filedObj: this.filedObj, data: data, disabled: disabled, changeSelect: this.changeSelect, selected: selected, dropStyle: this.dropStyle, initSelect: this.initSelect, initComboVal: initComboVal, formatterDropItem: formatterDropItem, clickMethod: this.bindSelectFn })))));
            }
            render() {
                const { children } = this.props;
                return children ? (React.createElement("div", { className: "m-flex-center" },
                    React.createElement("span", { className: "lab-tit" }, children),
                    this.renderCombox())) : this.renderCombox();
            }
        },
        _a.defaultProps = {
            idField: "id",
            textField: "text",
            childField: "children",
            width: 240,
            maxHeight: 240,
            defaultVal: "",
            clickOrCheckForbid: function () {
                return false;
            }
        },
        _a;
};
export default wrapComboHC;
